Documentation
¶
Overview ¶
Package v1beta1 contains API Schema definitions for the v1beta1 IPAM API.
Index ¶
- Constants
- Variables
- type IPAddress
- type IPAddressClaim
- func (in *IPAddressClaim) DeepCopy() *IPAddressClaim
- func (in *IPAddressClaim) DeepCopyInto(out *IPAddressClaim)
- func (in *IPAddressClaim) DeepCopyObject() runtime.Object
- func (m *IPAddressClaim) GetConditions() clusterv1.Conditions
- func (m *IPAddressClaim) GetV1Beta2Conditions() []metav1.Condition
- func (*IPAddressClaim) Hub()
- func (m *IPAddressClaim) SetConditions(conditions clusterv1.Conditions)
- func (m *IPAddressClaim) SetV1Beta2Conditions(conditions []metav1.Condition)
- type IPAddressClaimList
- type IPAddressClaimSpec
- type IPAddressClaimStatus
- type IPAddressClaimV1Beta2Status
- type IPAddressList
- type IPAddressSpec
Constants ¶
const ( // AllocationFailedReason is the reason used when allocating an IP address for a claim fails. More details should be // provided in the condition's message. // When the IP pool is full, [PoolExhaustedReason] should be used for better visibility instead. AllocationFailedReason = "AllocationFailed" // PoolNotReadyReason is the reason used when the referenced IP pool is not ready. PoolNotReadyReason = "PoolNotReady" // PoolExhaustedReason is the reason used when an IP pool referenced by an [IPAddressClaim] is full and no address // can be allocated for the claim. PoolExhaustedReason = "PoolExhausted" )
These reasons are intended to be used with failed Ready conditions on an IPAddressClaim.
Variables ¶
var ( // GroupVersion is group version used to register these objects. GroupVersion = schema.GroupVersion{Group: "ipam.cluster.x-k8s.io", Version: "v1beta1"} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = schemeBuilder.AddToScheme )
Functions ¶
This section is empty.
Types ¶
type IPAddress ¶
type IPAddress struct {
metav1.TypeMeta `json:",inline"`
// metadata is the standard object's metadata.
// More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
// +optional
metav1.ObjectMeta `json:"metadata,omitempty"`
// spec is the desired state of IPAddress.
// +optional
Spec IPAddressSpec `json:"spec,omitempty"`
}
IPAddress is the Schema for the ipaddress API.
func (*IPAddress) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IPAddress.
func (*IPAddress) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*IPAddress) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type IPAddressClaim ¶
type IPAddressClaim struct {
metav1.TypeMeta `json:",inline"`
// metadata is the standard object's metadata.
// More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
// +optional
metav1.ObjectMeta `json:"metadata,omitempty"`
// spec is the desired state of IPAddressClaim.
// +optional
Spec IPAddressClaimSpec `json:"spec,omitempty"`
// status is the observed state of IPAddressClaim.
// +optional
Status IPAddressClaimStatus `json:"status,omitempty"`
}
IPAddressClaim is the Schema for the ipaddressclaim API.
func (*IPAddressClaim) DeepCopy ¶
func (in *IPAddressClaim) DeepCopy() *IPAddressClaim
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IPAddressClaim.
func (*IPAddressClaim) DeepCopyInto ¶
func (in *IPAddressClaim) DeepCopyInto(out *IPAddressClaim)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*IPAddressClaim) DeepCopyObject ¶
func (in *IPAddressClaim) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*IPAddressClaim) GetConditions ¶
func (m *IPAddressClaim) GetConditions() clusterv1.Conditions
GetConditions returns the set of conditions for this object.
func (*IPAddressClaim) GetV1Beta2Conditions ¶ added in v1.10.0
func (m *IPAddressClaim) GetV1Beta2Conditions() []metav1.Condition
GetV1Beta2Conditions returns the set of conditions for this object.
func (*IPAddressClaim) Hub ¶
func (*IPAddressClaim) Hub()
func (*IPAddressClaim) SetConditions ¶
func (m *IPAddressClaim) SetConditions(conditions clusterv1.Conditions)
SetConditions sets the conditions on this object.
func (*IPAddressClaim) SetV1Beta2Conditions ¶ added in v1.10.0
func (m *IPAddressClaim) SetV1Beta2Conditions(conditions []metav1.Condition)
SetV1Beta2Conditions sets conditions for an API object.
type IPAddressClaimList ¶
type IPAddressClaimList struct {
metav1.TypeMeta `json:",inline"`
// metadata is the standard list's metadata.
// More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#lists-and-simple-kinds
// +optional
metav1.ListMeta `json:"metadata,omitempty"`
// items is the list of IPAddressClaims.
Items []IPAddressClaim `json:"items"`
}
IPAddressClaimList is a list of IPAddressClaims.
func (*IPAddressClaimList) DeepCopy ¶
func (in *IPAddressClaimList) DeepCopy() *IPAddressClaimList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IPAddressClaimList.
func (*IPAddressClaimList) DeepCopyInto ¶
func (in *IPAddressClaimList) DeepCopyInto(out *IPAddressClaimList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*IPAddressClaimList) DeepCopyObject ¶
func (in *IPAddressClaimList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*IPAddressClaimList) Hub ¶
func (*IPAddressClaimList) Hub()
type IPAddressClaimSpec ¶
type IPAddressClaimSpec struct {
// clusterName is the name of the Cluster this object belongs to.
// +optional
// +kubebuilder:validation:MinLength=1
// +kubebuilder:validation:MaxLength=63
ClusterName string `json:"clusterName,omitempty"`
// poolRef is a reference to the pool from which an IP address should be created.
// +required
PoolRef corev1.TypedLocalObjectReference `json:"poolRef"`
}
IPAddressClaimSpec is the desired state of an IPAddressClaim.
func (*IPAddressClaimSpec) DeepCopy ¶
func (in *IPAddressClaimSpec) DeepCopy() *IPAddressClaimSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IPAddressClaimSpec.
func (*IPAddressClaimSpec) DeepCopyInto ¶
func (in *IPAddressClaimSpec) DeepCopyInto(out *IPAddressClaimSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type IPAddressClaimStatus ¶
type IPAddressClaimStatus struct {
// addressRef is a reference to the address that was created for this claim.
// +optional
AddressRef corev1.LocalObjectReference `json:"addressRef,omitempty"`
// conditions summarises the current state of the IPAddressClaim
// +optional
Conditions clusterv1.Conditions `json:"conditions,omitempty"`
// v1beta2 groups all the fields that will be added or modified in IPAddressClaim's status with the V1Beta2 version.
// +optional
V1Beta2 *IPAddressClaimV1Beta2Status `json:"v1beta2,omitempty"`
}
IPAddressClaimStatus is the observed status of a IPAddressClaim.
func (*IPAddressClaimStatus) DeepCopy ¶
func (in *IPAddressClaimStatus) DeepCopy() *IPAddressClaimStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IPAddressClaimStatus.
func (*IPAddressClaimStatus) DeepCopyInto ¶
func (in *IPAddressClaimStatus) DeepCopyInto(out *IPAddressClaimStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type IPAddressClaimV1Beta2Status ¶ added in v1.10.0
type IPAddressClaimV1Beta2Status struct {
// conditions represents the observations of a IPAddressClaim's current state.
// +optional
// +listType=map
// +listMapKey=type
// +kubebuilder:validation:MaxItems=32
Conditions []metav1.Condition `json:"conditions,omitempty"`
}
IPAddressClaimV1Beta2Status groups all the fields that will be added or modified in IPAddressClaimStatus with the V1Beta2 version. See https://github.com/kubernetes-sigs/cluster-api/blob/main/docs/proposals/20240916-improve-status-in-CAPI-resources.md for more context.
func (*IPAddressClaimV1Beta2Status) DeepCopy ¶ added in v1.10.0
func (in *IPAddressClaimV1Beta2Status) DeepCopy() *IPAddressClaimV1Beta2Status
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IPAddressClaimV1Beta2Status.
func (*IPAddressClaimV1Beta2Status) DeepCopyInto ¶ added in v1.10.0
func (in *IPAddressClaimV1Beta2Status) DeepCopyInto(out *IPAddressClaimV1Beta2Status)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type IPAddressList ¶
type IPAddressList struct {
metav1.TypeMeta `json:",inline"`
// metadata is the standard list's metadata.
// More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#lists-and-simple-kinds
// +optional
metav1.ListMeta `json:"metadata,omitempty"`
// items is the list of IPAddresses.
Items []IPAddress `json:"items"`
}
IPAddressList is a list of IPAddress.
func (*IPAddressList) DeepCopy ¶
func (in *IPAddressList) DeepCopy() *IPAddressList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IPAddressList.
func (*IPAddressList) DeepCopyInto ¶
func (in *IPAddressList) DeepCopyInto(out *IPAddressList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*IPAddressList) DeepCopyObject ¶
func (in *IPAddressList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*IPAddressList) Hub ¶
func (*IPAddressList) Hub()
type IPAddressSpec ¶
type IPAddressSpec struct {
// claimRef is a reference to the claim this IPAddress was created for.
// +required
ClaimRef corev1.LocalObjectReference `json:"claimRef"`
// poolRef is a reference to the pool that this IPAddress was created from.
// +required
PoolRef corev1.TypedLocalObjectReference `json:"poolRef"`
// address is the IP address.
// +required
// +kubebuilder:validation:MinLength=1
// +kubebuilder:validation:MaxLength=39
Address string `json:"address"`
// prefix is the prefix of the address.
// +required
Prefix int `json:"prefix"`
// gateway is the network gateway of the network the address is from.
// +optional
// +kubebuilder:validation:MinLength=1
// +kubebuilder:validation:MaxLength=39
Gateway string `json:"gateway,omitempty"`
}
IPAddressSpec is the desired state of an IPAddress.
func (*IPAddressSpec) DeepCopy ¶
func (in *IPAddressSpec) DeepCopy() *IPAddressSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IPAddressSpec.
func (*IPAddressSpec) DeepCopyInto ¶
func (in *IPAddressSpec) DeepCopyInto(out *IPAddressSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.